ARAnchorManager class

Handles all anchor-related functionality of an ARView, including configuration and usage of collaborative sessions

Constructors

ARAnchorManager(int id, {bool debug = false})

Properties

debug → bool
Debugging status flag. If true, all platform calls are printed. Defaults to false.
final
hashCode → int
The hash code for this object.
no setterinherited
onAnchorDownloaded ↔ AnchorDownloadedHandler?
Callback that is triggered once an anchor has successfully been downloaded from the google cloud anchor API and resolved within the current scene
getter/setter pair
onAnchorUploaded ↔ AnchorUploadedHandler?
Callback that is triggered once an anchor has successfully been uploaded to the google cloud anchor API
getter/setter pair
pendingAnchors ↔ List<ARAnchor>
Reference to all anchors that are being uploaded to the google cloud anchor API
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addAnchor(ARAnchor anchor) → Future<bool?>
Add given anchor to the underlying AR scene
downloadAnchor(String cloudanchorid) → Future<bool?>
Try to download anchor with the given ID from the Google Cloud Anchor API and add it to the scene
initGoogleCloudAnchorMode() → dynamic
Activates collaborative AR mode (using Google Cloud Anchors)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAnchor(ARAnchor anchor) → dynamic
Remove given anchor and all its children from the AR Scene
toString() → String
A string representation of this object.
inherited
uploadAnchor(ARAnchor anchor) → Future<bool?>
Upload given anchor from the underlying AR scene to the Google Cloud Anchor API

Operators

operator ==(Object other) → bool
The equality operator.
inherited