ARPlaneAnchor class

An ARAnchor fixed to a tracked plane

Inheritance

Constructors

ARPlaneAnchor({required Matrix4 transformation, String? name, List<String>? childNodes, String? cloudanchorid, int? ttl})

Properties

childNodes ↔ List<String>
Names of ARNodes attached to this APlaneRAnchor
getter/setter pair
cloudanchorid ↔ String?
ID associated with the anchor after uploading it to the google cloud anchor API
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name → String
Determines the name of the ARAnchor Will be autogenerated if not defined.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transformation → Matrix4
Defines the anchor’s rotation, translation and scale in world coordinates.
finalinherited
ttl ↔ int?
Time to live of the anchor: Determines how long the anchor is stored once it is uploaded to the google cloud anchor API (optional, defaults to 1 day (24hours))
getter/setter pair
type → AnchorType
Specifies the AnchorType of this ARAnchor
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes an ARAnchor
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) → ARPlaneAnchor